class RelatedTagCalculator
  def self.find_tags(tag, limit)
    CurrentUser.without_safe_mode do
      Post.with_timeout(5_000, []) do
        Post.tag_match(tag).limit(limit).select("posts.tag_string").reorder("posts.md5").map(&:tag_string)
      end
    end
  end

  def self.calculate_from_sample_to_array(tags, category_constraint = nil)
    convert_hash_to_array(calculate_from_sample(tags, Danbooru.config.post_sample_size, category_constraint))
  end

  def self.calculate_from_post_set_to_array(post_set, category_constraint = nil)
    convert_hash_to_array(calculate_from_post_set(post_set, category_constraint))
  end

  def self.calculate_from_post_set(post_set, category_constraint = nil)
    counts = Hash.new {|h, k| h[k] = 0}

    post_set.posts.each do |post|
      post.tag_array.each do |tag|
        category = Tag.category_for(tag)
        if category_constraint
          if category == category_constraint
            counts[tag] += 1
          end
        else
          counts[tag] += 1
        end
      end
    end

    counts
  end

  def self.calculate_from_sample(tags, limit, category_constraint = nil)
    counts = Hash.new {|h, k| h[k] = 0}

    find_tags(tags, limit).each do |tags|
      tag_array = Tag.scan_tags(tags)
      if category_constraint
        tag_array.each do |tag|
          category = Tag.category_for(tag)
          if category == category_constraint
            counts[tag] += 1
          end
        end
      else
        tag_array.each do |tag|
          counts[tag] += 1
        end
      end
    end

    counts
  end

  def self.convert_hash_to_array(hash)
    hash.to_a.sort_by {|x| -x[1]}.slice(0, 25)
  end

  def self.convert_hash_to_string(hash)
    convert_hash_to_array(hash).flatten.join(" ")
  end
end
